@@ -48,13 +48,13 @@ class RedizConventions(MicroConventions):
 
 
         self.WARNINGS_TTL = int(60 * 60)  # TODO: allow configuation
-        self.WARNINGS_LIMIT = 1000
+        self.WARNINGS_LIMIT = 500
         self.CONFIRMS_TTL = int(error_ttl or 60 * 60)  # Number of seconds that set execution error logs are persisted
         self.ERROR_TTL = int(error_ttl or 24* 60 * 60)     # Number of seconds that set execution error logs are persisted
         self.CONFIRMS_TTL = int(error_ttl or 60 * 60)  # Number of seconds that set execution error logs are persisted
-        self.ERROR_LIMIT = int(error_limit or 1000)    # Number of error messages to keep per write key
-        self.CONFIRMS_LIMIT = int(error_limit or 1000) # Number of error messages to keep per write key
-        self.TRANSACTIONS_LIMIT = 1000
+        self.ERROR_LIMIT = int(error_limit or 500)    # Number of error messages to keep per write key
+        self.CONFIRMS_LIMIT = int(error_limit or 500) # Number of error messages to keep per write key
+        self.TRANSACTIONS_LIMIT = 500
 
         # User transparent temporal and other config
         self.MIN_LEN = int(self.min_len)                     # FIXME: Get rid of MIN_LEN and use min_len instead
@@ -63,8 +63,8 @@ class RedizConventions(MicroConventions):
         self.DELAYS = delays or [1, 5]
         self.ZDELAYS = [self.DELAYS[0],self.DELAYS[-1]]
         self.CONFIRMS_MAX = 5  # Maximum number of confirmations when using mset()
-        self.NOISE = 0.1 / self.num_predictions  # Tie-breaking / smoothing noise added to predictions
-        self.NUM_WINNERS = 10   # Maximum number of winning tickets
+        self.NOISE = 0.00000001 # Tie-breaking / smoothing noise added to predictions
+        self.NUM_WINNERS = 1000  # Maximum number of winning tickets
 
         # Implementation details: private reserved redis keys and prefixes.
         self._obscurity = (obscurity or "obscure") + self.SEP
@@ -86,10 +86,11 @@ class RedizConventions(MicroConventions):
         self._DISCOUNT = 0.9            # Transfers
         self._REPOS = self._obscurity + "repos"
         self._AWARDS = self._obscurity + "awards"
+        self._EMAILS = self._obscurity + "emails"
 
         # Other implementation config
         self._CANCEL_GRACE = 45
-        self._DELAY_GRACE = int(delay_grace or 5)  # Seconds beyond the schedule time when promise data expires
+        self._DELAY_GRACE = int(delay_grace or 10)  # Seconds beyond the schedule time when promise data expires
         self._DEFAULT_MODEL_STD = 1.0  # Noise added for self-prediction
         self._WINDOWS = windows  # Sizes of neighbourhoods around truth used in countback ... don't make too big or it hits performance
         self._INSTANT_RECALL = instant_recall or False
@@ -97,6 +98,7 @@ class RedizConventions(MicroConventions):
         self._TRANSACTIONS_TTL = int( transactions_ttl or 24 * (60 * 60) )  # How long to keep transactions stream for inactive write_keys
         self._LEADERBOARD_TTL  = int( 24 * (60 * 60)*60 )  # How long to keep transactions stream for inactive write_keys
         self._CREATE_COST = 500
+        self._PARTICIPATION_INCENTIVE = 0.01
 
     @staticmethod
     def assert_not_in_reserved_namespace(names, *args):
@@ -335,7 +337,7 @@ class RedizConventions(MicroConventions):
 
     def _random_promised_name(self, name):
         name_stem = os.path.splitext(name)[0]
-        return self._PROMISED + str(uuid.uuid4())[:8] + self.SEP + name_stem + '.json'
+        return self._PROMISED + str(uuid.uuid4())[:12] + self.SEP + name_stem + '.json'
 
     def _copy_promise(self, source, destination):
         return source + self.COPY_SEP + destination
@@ -436,7 +438,8 @@ class RedizConventions(MicroConventions):
 
     def _cost_based_distribution_ttl(self,budget):
         """ Time to live for samples ... mostly budget independent """
-        return int( max(self.DELAYS)+self._DELAY_GRACE+60+budget )
+        return 60*60*24*3
+        #return int( max(self.DELAYS)+self._DELAY_GRACE+60+budget )
 
     # --------------------------------------------------------------------------
     #            Redis version/capability inference
